@@ -14,10 +14,13 @@ hpo <- read_fileMDB(
    as_memoMDB()
 count_records(hpo)
 
+## Too long on win-builder.r-project.org
+\dontrun{
+   
 hpoSlice <- slice(hpo, HPO_diseases=1:10)
 count_records(hpoSlice)
 
-if(requireNamespace("stringr", quietly = TRUE)){
+if("stringr" %in% installed.packages()[,"Package"]){
    epilHP <- filter(
       hpo,
       HPO_diseases=stringr::str_detect(
@@ -26,3 +29,5 @@ if(requireNamespace("stringr", quietly = TRUE)){
    )
    count_records(epilHP)
 }
+
+}
